/*******************************************************************************
 * Copyright (C) 2017 Philipp Spohr
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 ******************************************************************************/
package de.hhu.ba.yoshikoWrapper.gui;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.BorderFactory;
import javax.swing.BoxLayout;
import javax.swing.JButton;
import javax.swing.JFileChooser;
import javax.swing.JLabel;
import javax.swing.border.EtchedBorder;

import org.cytoscape.util.swing.BasicCollapsiblePanel;

import de.hhu.ba.yoshikoWrapper.core.LocalizationManager;
import de.hhu.ba.yoshikoWrapper.core.YoshikoLoader;
import de.hhu.ba.yoshikoWrapper.swig.LibraryInterface;

@SuppressWarnings("serial")
public class LibraryPanel extends ComfortCollapsiblePanel {
	
	//SYMBOLIC LINKS
	private LibraryPanel self = this;
	
	private LibStatusPanel libStatusPanel;
	private JButton searchLibButton;
	private JLabel yoshikoVersionLabel;
	
	
	public LibraryPanel() {
		super(LocalizationManager.get("libraryPanel"));
		this.setLayout(new BoxLayout(this,BoxLayout.Y_AXIS));
		//SWING COMPONENT INITIALIZATION
		libStatusPanel = new LibStatusPanel();
		searchLibButton = new JButton(LocalizationManager.get("resolveLibPath"));
		yoshikoVersionLabel = new JLabel(LocalizationManager.get("yoshVersion"));

		libStatusPanel.setStyle(YoshikoLoader.isLibraryLoaded());
		
		if (YoshikoLoader.isLibraryLoaded()) {
			yoshikoVersionLabel.setText(LibraryInterface.getVersionString());
			searchLibButton.setEnabled(false);
		}
		

		searchLibButton.addActionListener(new ActionListener() {
			@Override
			public void actionPerformed(ActionEvent e) {
				final YLibChooser c = new YLibChooser();
				int returnVal = c.showOpenDialog(self);
				if (returnVal == JFileChooser.APPROVE_OPTION) {
					YoshikoLoader.loadLibrary(c.getSelectedFile().getAbsolutePath());
				}
				libStatusPanel.setStyle(YoshikoLoader.isLibraryLoaded());
				yoshikoVersionLabel.setText(LibraryInterface.getVersionString());
				searchLibButton.setEnabled(false);
			}
		});
		
		SwingUtil.addAll(this,libStatusPanel,yoshikoVersionLabel,searchLibButton);

	}
}
