/*******************************************************************************
 * Copyright (C) 2017 Philipp Spohr
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 ******************************************************************************/
package de.hhu.ba.yoshikoWrapper.gui;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.BorderFactory;
import javax.swing.BoxLayout;
import javax.swing.ButtonGroup;
import javax.swing.JCheckBox;
import javax.swing.JRadioButton;
import javax.swing.border.Border;
import javax.swing.border.EtchedBorder;

import org.cytoscape.util.swing.BasicCollapsiblePanel;

import de.hhu.ba.yoshikoWrapper.core.LocalizationManager;

@SuppressWarnings("serial")
public class OperationModePanel extends ComfortCollapsiblePanel{
	private final JRadioButton useHeuristic;
	private final JRadioButton useILP;
	private final TimeLimitSetter timeLimitSetter;
	private final SolutionNumberChooser solutionNumberChooser;
	private final JCheckBox useTriangleCutsBox;
	private final JCheckBox usePartitionCutsBox;
	
	private final ButtonGroup heuristicGroup;

	public OperationModePanel() {
		super(LocalizationManager.get("operationMode"));
		this.setLayout(new BoxLayout(this,BoxLayout.Y_AXIS));
		
		heuristicGroup = new ButtonGroup();
		useILP = new JRadioButton("Use Integer Linear Programming");
		useILP.setSelected(true);

		useHeuristic = new JRadioButton("Use Heuristic");
		heuristicGroup.add(useILP);
		heuristicGroup.add(useHeuristic);
		
		solutionNumberChooser = new SolutionNumberChooser();
		

		timeLimitSetter = new TimeLimitSetter();
				
		useTriangleCutsBox = new JCheckBox("Use Triangle Cuts");
		usePartitionCutsBox = new JCheckBox("Use Partition Cuts");
		
		//Link time limit option to ILP
		useILP.addActionListener(ilpHeuristicSwitch);
		useHeuristic.addActionListener(ilpHeuristicSwitch);
		

		SwingUtil.addAll(this,useILP,useHeuristic,solutionNumberChooser,timeLimitSetter,useTriangleCutsBox,usePartitionCutsBox);

	}
	
	ActionListener ilpHeuristicSwitch = new ActionListener() {
		@Override
		public void actionPerformed(ActionEvent e) {
			if (useILP.isSelected()) {
				timeLimitSetter.setEnabled(true);
				useTriangleCutsBox.setEnabled(true);
				usePartitionCutsBox.setEnabled(true);
				solutionNumberChooser.setEnabled(true);
			}
			else {
				timeLimitSetter.setEnabled(false);
				useTriangleCutsBox.setEnabled(false);
				usePartitionCutsBox.setEnabled(false);
				solutionNumberChooser.setEnabled(false);
			}
		}	
	};
	
	//SETTER GETTER

	public int getTimeLimit() {
		return timeLimitSetter.getTimeLimit();
	}

	public boolean useTriangleCuts() {
		return useTriangleCutsBox.isSelected();
	}

	public boolean usePartitionCuts() {
		return usePartitionCutsBox.isSelected();
	}

	public boolean useHeuristic() {
		return useHeuristic.isSelected();
	}

	public int getSolCount() {
		return solutionNumberChooser.getSolCount();
	}
}
